Tile
====

.. currentmodule:: toasty.toast

.. autoclass:: Tile
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Tile.corners
      ~Tile.increasing
      ~Tile.pos

   .. rubric:: Attributes Documentation

   .. autoattribute:: corners
   .. autoattribute:: increasing
   .. autoattribute:: pos
